﻿using System;
using System.Text;
using System.Threading;
using xidcusb;

namespace testcs
{
    class testapp
    {
        private static void print_state(State state)
        {
            Console.WriteLine("state: {0} pwm: {1} rpm: {2} pos: {3} temp: {4} flags: {5}",
                        state.device_state,
                        state.pwm_state,
                        state.current_rpm,
                        state.current_position,
                        state.current_temp,
                        state.flags);
        }

        static void Main(string[] args)
        {
            int device = -1;
            Result res;
            try
            {
                string[] devices;
                res = API.enumerate_devices(out devices, 1);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());

                if (devices.Length == 0)
                    throw new Exception("No devices");

                foreach (String dev in devices)
                {
                    System.Console.WriteLine("Found device {0}", dev);
                }
                
                //String deviceName = "\\\\.\\COM8";
                String deviceName = devices[0];
                System.Console.WriteLine("Using device {0}", deviceName);

                device = API.open_device(deviceName);
                Console.WriteLine("Device {0}", device);

                State state;
                res = API.get_status(device, out state);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());
                print_state(state);

                res = API.command_zero(device);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());

                res = API.get_status(device, out state);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());
                print_state(state);

                Console.WriteLine("running...");
                res = API.command_right(device);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());

                Thread.Sleep(1 * 1000);

                res = API.get_status(device, out state);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());
                print_state(state);

                Thread.Sleep(10 * 1000);

                Console.WriteLine("stopping...");
                res = API.command_stop(device);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());

                res = API.get_status(device, out state);
                if (res != Result.ok)
                    throw new Exception("Error " + res.ToString());
                print_state(state);

                Console.WriteLine("Done...");
            }
            catch (Exception e)
            {
                Console.WriteLine("Exception " + e.Message);
            }
            finally
            {
                if (device != -1)
                    API.close_device(device);
            }
            //Console.ReadKey();
        }
    }
}
